# たまごのお店
むこたま

むこたま 柏の葉店
〒2770871
千葉県柏市若柴186番地 中央146街区1
ARAGE 112
KOIL LINK G
TEL:0471-28-8905
https://www.mukodai.com
登録番号: T7040002093726
端末番号:6B4A

AM9:00~PM7:00

お買い上げ、誠にありがとうございます。
またのお越しをお待ちしております。
2024-11-13 13:26:15
端末取引ID:50631

むこたまソフト ※ ¥529
小計 | ¥529
合計 | ¥529
内消費税 | (¥39)
(8%対象 ¥529 内消費税 ¥39)
合計点数 | 1点
お預り金額 | ¥1,000
お釣り | ¥471

注) ※は軽減税率(8%)適用

オンラインでもご購入いただけます!
http://www.mukotama.com/

No.7314719750041